"""
Created on 02.07.2021
This is a program to monitor all the expiring values within the google sheet containing the Warrants
@author: baier
"""

import datetime
import pandas as pd
from accessOutlookEmail import create_account, send_email
from kursversorgung_google_sheets import createPrettyHTMLTable, create_client_with_scope

account = create_account('baier@orcacapital.de', 'Malfurion321')
client = create_client_with_scope()
ws = client.open('KursversorgungWarrants').worksheet('Kurse')


def getExpiringWarrants():
    ticker = ws.col_values(1)[1:]
    dateCol = ws.col_values(7)[1:]

    df = pd.DataFrame(list(zip(ticker, dateCol)), columns=['Ticker', 'Laufzeit'])
    today = datetime.date.today()
    timedelta = datetime.timedelta(31)
    endOfMonth = (today + timedelta).strftime('%Y-%m-%d')

    df.index += 2  # setz Index zu Zeilen in Excel
    df = df[df['Laufzeit'] != '']  # Filter auf alle Zeilen, die eine Laufzeit besitzen

    # sortiere DF nach der Laufzeit
    df['Laufzeit'] = pd.to_datetime(df['Laufzeit'], format='%d.%m.%Y')
    df = df[df['Laufzeit'] < endOfMonth]
    df = df.sort_values(by=['Laufzeit'])

    table = createPrettyHTMLTable(df)

    send_email(account, 'Auslaufende Warrants', table, ['dichtl@orcacapital.de', 'koenig@orcacapital.de',
                                                        'schroedl@orcacapital.de', 'grodon@orcacapital.de'])
    print('Monthly Report has been sent!')


def main():
    getExpiringWarrants()


if __name__ == '__main__':
    main()



'''from authenticate import create_client_with_scope
# from Kursversorgung import callBloombergApi
client = create_client_with_scope()

ws = client.open('KursversorgungWarrants').worksheet('Kurse')
wsPP1 = client.open('Private Placements').worksheet('Private Placements')

ticker = ws.col_values(1)[1:]
ticker_pp = wsPP1.col_values(1)[1:]'''

'''ticker = open(r"ticker_file.txt").read().splitlines()
tickerPP = open(r"ticker_pp_file.txt").read().splitlines()
print()

set_ticker = set(ticker)
set_tickerPP = set(tickerPP)
set_total = set.union(set_ticker, set_tickerPP)

print(len(ticker) + len(tickerPP), len(set_ticker), len(set_tickerPP))
print(len(set_total))
print(set_total)


textfile = open("ticker_file.txt", "w")
for element in ticker:
    textfile.write(element + "\n")
textfile.close()

textfile = open("ticker_pp_file.txt", "w")
for element in tickerPP:
    textfile.write(element + "\n")
textfile.close()
'''
'''from Kursversorgung import callBloombergApi, updateLastSplits, ws, updateSecurityName, updateLast, checkBloombergConnection
# ticker = open(r"ticker_file.txt").read().splitlines()
# ticker_pp = open(r"ticker_pp_file.txt").read().splitlines()
set_total = set.union(set(ticker), set(ticker_pp))

df = callBloombergApi(ticker, ticker_pp, fld1='Last_Price', fld2='Last_All_Sessions', fld3='Security_Name',
                      fld4='EXCH_Market_Status', fld5='EQY_Split_Ratio', fld6='EQY_Split_DT')

# updateLastSplits(ticker, df, '01.12.2021 08:32:00')
# updateSecurityName(ticker, ticker_pp, df, '01.12.2021 08:58:00')
# ws.update_cell(1, 21, '01.12.2021 08:58:00')
print(updateLast(ticker, ticker_pp, df, '01.12.2021 10:29:00'))
import pandas as pd
d = {'col1': [1, 2], 'col2': [3, 4], 'col3': [5, 6]}
df = pd.DataFrame(data=d)

df = df[['col2', 'col3']]
print(df)'''
from kursversorgung_google_sheets import kursversorgung



from setuptools import setup, find_packages

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent


VERSION = '0.0.13'
DESCRIPTION = 'Kursversorgung Google Sheets'
LONG_DESCRIPTION = (this_directory / "README.md").read_text()

# Setting up
setup(
    name="kursversorgung_google_sheets",
    version=VERSION,
    author="Valentin Baier",
    author_email="valentin_baier@gmx.de",
    license_files=('LICENSE.txt',),
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    include_package_data=True,
    install_requires=['exchangelib', 'setuptools', 'gspread', 'pandas', 'oauth2client', 'pretty_html_table',
                      'google-api-python-client', 'bs4', 'beautifulsoup4', 'blpapi', 'xbbg', 'future', 'tzdata'],
    keywords=['python', 'kursversorgung', 'warrants', 'updateLast', 'updateSecurityName', 'updateLastSplits'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
